Module types

Module types 

Types used as operation parameters and responses.

Modules

defaults
Generation of default values for serde.
error
Error types.

Structs

AutoDeploy
AutoDeploy
BackgroundWorkerDetails
BackgroundWorkerDetails
BackgroundWorkerDetailsAutoscaling
BackgroundWorkerDetailsAutoscaling
BackgroundWorkerDetailsAutoscalingCriteria
BackgroundWorkerDetailsAutoscalingCriteria
BackgroundWorkerDetailsAutoscalingCriteriaCpu
BackgroundWorkerDetailsAutoscalingCriteriaCpu
BackgroundWorkerDetailsAutoscalingCriteriaMemory
BackgroundWorkerDetailsAutoscalingCriteriaMemory
BackgroundWorkerDetailsDisk
BackgroundWorkerDetailsDisk
BackgroundWorkerDetailsDiskId
BackgroundWorkerDetailsDiskId
BackgroundWorkerDetailsPost
BackgroundWorkerDetailsPost
BackgroundWorkerDetailsPostAutoscaling
BackgroundWorkerDetailsPostAutoscaling
BackgroundWorkerDetailsPostAutoscalingCriteria
BackgroundWorkerDetailsPostAutoscalingCriteria
BackgroundWorkerDetailsPostAutoscalingCriteriaCpu
BackgroundWorkerDetailsPostAutoscalingCriteriaCpu
BackgroundWorkerDetailsPostAutoscalingCriteriaMemory
BackgroundWorkerDetailsPostAutoscalingCriteriaMemory
BuildFilter
BuildFilter
BuildPlan
BuildPlan
Cache
Cache
CidrBlockAndDescription
CidrBlockAndDescription
CreateDeployBody
CreateDeployBody
CronJobDetails
CronJobDetails
CronJobDetailsPost
CronJobDetailsPost
Cursor
Cursor
DatabaseRole
DatabaseRole
DatabaseStatus
DatabaseStatus
Deploy
Deploy
DeployCommit
DeployCommit
DeployImage
Image information used when creating the deploy. Not present for Git-backed deploys
DeployList
DeployList
DeployMode
Controls deployment behavior when triggering a deploy.
DeployStatus
DeployStatus
DeployWithCursor
DeployWithCursor
DockerDetails
DockerDetails
DockerDetailsPost
DockerDetailsPost
EnvVar
EnvVar
EnvVarWithCursor
EnvVarWithCursor
Error
Error
HeaderInput
HeaderInput
Image
Image
ListLogsResponse
A run of a cron job
ListLogsResponseLogsItem
A log entry with metadata
ListLogsResponseLogsItemLabelsItem
A log label
MaintenanceMode
MaintenanceMode
MaxShutdownDelaySeconds
The maximum amount of time (in seconds) that Render waits for your application process to exit gracefully after sending it a SIGTERM signal.
NativeEnvironmentDetails
NativeEnvironmentDetails
NativeEnvironmentDetailsPost
Fields for native environment (runtime) services
NotifySetting
NotifySetting
Owner
Owner
PaidPlan
Defaults to starter when creating a new database.
PatchRouteResponse
PatchRouteResponse
Plan
The instance type to use. Legacy variants (*_legacy) identify grandfathered plans no longer offered for new services. Note that base services on any paid instance type can’t create preview instances with the free instance type.
Postgres
Postgres
PostgresConnectionInfo
PostgresConnectionInfo
PostgresDetail
PostgresDetail
PostgresDetailMaintenance
PostgresDetailMaintenance
PostgresDetailMaintenanceId
PostgresDetailMaintenanceId
PostgresParameterOverrides
PostgresParameterOverrides
PostgresPostInput
Input for creating a database
PostgresVersion
The PostgreSQL version
PostgresWithCursor
PostgresWithCursor
Previews
Previews
PrivateServiceDetails
PrivateServiceDetails
PrivateServiceDetailsAutoscaling
PrivateServiceDetailsAutoscaling
PrivateServiceDetailsAutoscalingCriteria
PrivateServiceDetailsAutoscalingCriteria
PrivateServiceDetailsAutoscalingCriteriaCpu
PrivateServiceDetailsAutoscalingCriteriaCpu
PrivateServiceDetailsAutoscalingCriteriaMemory
PrivateServiceDetailsAutoscalingCriteriaMemory
PrivateServiceDetailsDisk
PrivateServiceDetailsDisk
PrivateServiceDetailsDiskId
PrivateServiceDetailsDiskId
PrivateServiceDetailsPost
PrivateServiceDetailsPost
PrivateServiceDetailsPostAutoscaling
PrivateServiceDetailsPostAutoscaling
PrivateServiceDetailsPostAutoscalingCriteria
PrivateServiceDetailsPostAutoscalingCriteria
PrivateServiceDetailsPostAutoscalingCriteriaCpu
PrivateServiceDetailsPostAutoscalingCriteriaCpu
PrivateServiceDetailsPostAutoscalingCriteriaMemory
PrivateServiceDetailsPostAutoscalingCriteriaMemory
PullRequestPreviewsEnabled
This field has been deprecated. previews.generation should be used in its place.
ReadReplica
ReadReplica
ReadReplicaInput
ReadReplicaInput
ReadReplicas
ReadReplicas
ReadReplicasInput
ReadReplicasInput
Region
Defaults to “oregon”
RegistryCredential
RegistryCredential
RegistryCredentialRegistry
The registry to use this credential with
RegistryCredentialSummary
RegistryCredentialSummary
RenderSubdomainPolicy
Controls whether render.com subdomains are available for the service
Resource
Resource
Route
Route
RoutePatch
RoutePatch
RoutePost
RoutePost
RoutePut
RoutePut
RouteType
RouteType
RouteWithCursor
RouteWithCursor
SecretFileInput
SecretFileInput
ServerPort
ServerPort
Service
Service
ServiceAndDeploy
ServiceAndDeploy
ServiceDisk
ServiceDisk
ServiceEnv
This field has been deprecated, runtime should be used in its place.
ServiceList
ServiceList
ServicePost
ServicePost
ServiceRuntime
Runtime
ServiceType
ServiceType
ServiceWithCursor
ServiceWithCursor
SshAddress
The SSH address for the service. Only present for services that have SSH enabled.
StaticSiteDetails
StaticSiteDetails
StaticSiteDetailsPost
StaticSiteDetailsPost
SuspenderType
SuspenderType
WebServiceDetails
WebServiceDetails
WebServiceDetailsAutoscaling
WebServiceDetailsAutoscaling
WebServiceDetailsAutoscalingCriteria
WebServiceDetailsAutoscalingCriteria
WebServiceDetailsAutoscalingCriteriaCpu
WebServiceDetailsAutoscalingCriteriaCpu
WebServiceDetailsAutoscalingCriteriaMemory
WebServiceDetailsAutoscalingCriteriaMemory
WebServiceDetailsDisk
WebServiceDetailsDisk
WebServiceDetailsDiskId
WebServiceDetailsDiskId
WebServiceDetailsPost
WebServiceDetailsPost
WebServiceDetailsPostAutoscaling
WebServiceDetailsPostAutoscaling
WebServiceDetailsPostAutoscalingCriteria
WebServiceDetailsPostAutoscalingCriteria
WebServiceDetailsPostAutoscalingCriteriaCpu
WebServiceDetailsPostAutoscalingCriteriaCpu
WebServiceDetailsPostAutoscalingCriteriaMemory
WebServiceDetailsPostAutoscalingCriteriaMemory

Enums

EnvSpecificDetails
EnvSpecificDetails
EnvSpecificDetailsPost
EnvSpecificDetailsPost
ServicePostEnvVarsItem
ServicePostEnvVarsItem
ServicePostServiceDetails
ServicePostServiceDetails
ServiceServiceDetails
ServiceServiceDetails
UpdateEnvVarsForServiceBodyItem
UpdateEnvVarsForServiceBodyItem