pub struct DeployImage {
pub ref_: Option<String>,
pub registry_credential: Option<String>,
pub sha: Option<String>,
}Expand description
Image information used when creating the deploy. Not present for Git-backed deploys
JSON schema
{
"description": "Image information used when creating the deploy. Not
present for Git-backed deploys",
"type": "object",
"properties": {
"ref": {
"description": "Image reference used when creating the deploy",
"type": "string"
},
"registryCredential": {
"description": "Name of credential used to pull the image, if
provided",
"type": "string"
},
"sha": {
"description": "SHA that the image reference was resolved to when
creating the deploy",
"type": "string"
}
}
}Fields
ref_: Option<String>Image reference used when creating the deploy
registry_credential: Option<String>Name of credential used to pull the image, if provided
sha: Option<String>SHA that the image reference was resolved to when creating the deploy