pub struct HeaderInput {
pub name: Option<String>,
pub path: Option<String>,
pub value: Option<String>,
}Expand description
HeaderInput
JSON schema
{
"type": "object",
"properties": {
"name": {
"description": "Header name",
"examples": [
"Cache-Control"
],
"type": "string"
},
"path": {
"description": "The request path to add the header to. Wildcards
will cause headers to be applied to all matching paths.",
"examples": [
"/static/*"
],
"type": "string"
},
"value": {
"description": "Header value",
"examples": [
"public, max-age=604800"
],
"type": "string"
}
}
}Fields
name: Option<String>Header name
path: Option<String>The request path to add the header to. Wildcards will cause headers to be applied to all matching paths.
value: Option<String>Header value