pub struct Image {
pub image_path: Option<String>,
pub owner_id: Option<String>,
pub registry_credential_id: Option<String>,
}Expand description
Image
JSON schema
{
"type": "object",
"properties": {
"imagePath": {
"description": "Path to the image used for this server (e.g
docker.io/library/nginx:latest).",
"type": "string"
},
"ownerId": {
"description": "The ID of the owner for this image. This should
match the owner of the service as well as the owner of any specified
registry credential.",
"type": "string"
},
"registryCredentialId": {
"description": "Optional reference to the registry credential
passed to the image repository to retrieve this image.",
"type": "string"
}
}
}Fields
image_path: Option<String>Path to the image used for this server (e.g docker.io/library/nginx:latest).
owner_id: Option<String>The ID of the owner for this image. This should match the owner of the service as well as the owner of any specified registry credential.
registry_credential_id: Option<String>Optional reference to the registry credential passed to the image repository to retrieve this image.