pub struct ListLogsResponse {
pub has_more: Option<bool>,
pub logs: Option<Vec<ListLogsResponseLogsItem>>,
pub next_end_time: Option<DateTime<Utc>>,
pub next_start_time: Option<DateTime<Utc>>,
}Expand description
A run of a cron job
JSON schema
{
"description": "A run of a cron job",
"type": "object",
"properties": {
"hasMore": {
"description": "True if there are more logs to fetch",
"type": "boolean"
},
"logs": {
"type": "array",
"items": {
"description": "A log entry with metadata",
"type": "object",
"properties": {
"id": {
"description": "A unique ID of the log entry",
"type": "string"
},
"labels": {
"type": "array",
"items": {
"description": "A log label",
"type": "object",
"properties": {
"name": {
"description": "The name of the log label",
"type": "string"
},
"value": {
"description": "The value of the log label",
"type": "string"
}
}
}
},
"message": {
"description": "The message of the log entry",
"type": "string"
},
"timestamp": {
"description": "The timestamp of the log entry",
"type": "string",
"format": "date-time"
}
}
}
},
"nextEndTime": {
"description": "The end time to use in the next query to fetch the
next set of logs",
"examples": [
"2021-07-15T07:20:05.777035-07:00"
],
"type": "string",
"format": "date-time"
},
"nextStartTime": {
"description": "The start time to use in the next query to fetch
the next set of logs",
"examples": [
"2021-07-15T07:20:05.777035-07:00"
],
"type": "string",
"format": "date-time"
}
}
}Fields
has_more: Option<bool>True if there are more logs to fetch
logs: Option<Vec<ListLogsResponseLogsItem>>next_end_time: Option<DateTime<Utc>>The end time to use in the next query to fetch the next set of logs
next_start_time: Option<DateTime<Utc>>The start time to use in the next query to fetch the next set of logs