pub struct PostgresDetail {Show 25 fields
pub created_at: Option<DateTime<Utc>>,
pub dashboard_url: Option<String>,
pub database_name: Option<String>,
pub database_user: Option<String>,
pub disk_autoscaling_enabled: Option<bool>,
pub disk_size_gb: Option<i64>,
pub environment_id: Option<String>,
pub expires_at: Option<DateTime<Utc>>,
pub high_availability_enabled: Option<bool>,
pub id: Option<String>,
pub ip_allow_list: Vec<CidrBlockAndDescription>,
pub maintenance: Option<PostgresDetailMaintenance>,
pub name: Option<String>,
pub owner: Option<Owner>,
pub parameter_overrides: Option<PostgresParameterOverrides>,
pub plan: Option<String>,
pub primary_postgres_id: Option<String>,
pub read_replicas: Option<ReadReplicas>,
pub region: Option<Region>,
pub role: Option<DatabaseRole>,
pub status: Option<DatabaseStatus>,
pub suspended: Option<String>,
pub suspenders: Vec<SuspenderType>,
pub updated_at: Option<DateTime<Utc>>,
pub version: Option<PostgresVersion>,
}Expand description
PostgresDetail
JSON schema
{
"type": "object",
"properties": {
"createdAt": {
"type": "string",
"format": "date-time"
},
"dashboardUrl": {
"description": "The URL to view the Postgres instance in the Render
Dashboard",
"type": "string"
},
"databaseName": {
"type": "string"
},
"databaseUser": {
"type": "string"
},
"diskAutoscalingEnabled": {
"type": "boolean"
},
"diskSizeGB": {
"type": "integer"
},
"environmentId": {
"type": "string"
},
"expiresAt": {
"description": "The time at which the database will be expire.
Applies to free tier databases only.",
"type": "string",
"format": "date-time"
},
"highAvailabilityEnabled": {
"type": "boolean"
},
"id": {
"type": "string"
},
"ipAllowList": {
"type": "array",
"items": {
"$ref": "#/components/schemas/cidrBlockAndDescription"
}
},
"maintenance": {
"type": "object",
"properties": {
"id": {
"examples": [
"mrn-cph1rs3idesc73a2b2mg"
],
"type": "string",
"pattern": "^mrn-[0-9a-z]{20}$"
},
"pendingMaintenanceBy": {
"description": "If present, the maintenance run cannot be
scheduled for later than this date-time.",
"type": "string",
"format": "date-time"
},
"scheduledAt": {
"type": "string",
"format": "date-time"
},
"state": {
"type": "string"
},
"type": {
"type": "string"
}
}
},
"name": {
"type": "string"
},
"owner": {
"$ref": "#/components/schemas/owner"
},
"parameterOverrides": {
"$ref": "#/components/schemas/postgresParameterOverrides"
},
"plan": {
"type": "string"
},
"primaryPostgresID": {
"type": "string"
},
"readReplicas": {
"$ref": "#/components/schemas/readReplicas"
},
"region": {
"$ref": "#/components/schemas/region"
},
"role": {
"$ref": "#/components/schemas/databaseRole"
},
"status": {
"$ref": "#/components/schemas/databaseStatus"
},
"suspended": {
"type": "string"
},
"suspenders": {
"type": "array",
"items": {
"$ref": "#/components/schemas/suspenderType"
}
},
"updatedAt": {
"type": "string",
"format": "date-time"
},
"version": {
"$ref": "#/components/schemas/postgresVersion"
}
}
}Fields
created_at: Option<DateTime<Utc>>dashboard_url: Option<String>The URL to view the Postgres instance in the Render Dashboard
database_name: Option<String>database_user: Option<String>disk_autoscaling_enabled: Option<bool>disk_size_gb: Option<i64>environment_id: Option<String>expires_at: Option<DateTime<Utc>>The time at which the database will be expire. Applies to free tier databases only.
high_availability_enabled: Option<bool>id: Option<String>ip_allow_list: Vec<CidrBlockAndDescription>maintenance: Option<PostgresDetailMaintenance>name: Option<String>owner: Option<Owner>parameter_overrides: Option<PostgresParameterOverrides>plan: Option<String>primary_postgres_id: Option<String>read_replicas: Option<ReadReplicas>region: Option<Region>role: Option<DatabaseRole>status: Option<DatabaseStatus>suspended: Option<String>suspenders: Vec<SuspenderType>updated_at: Option<DateTime<Utc>>version: Option<PostgresVersion>Trait Implementations
Sourceimpl Clone for PostgresDetail
impl Clone for PostgresDetail
Sourcefn clone(&self) -> PostgresDetail
fn clone(&self) -> PostgresDetail
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PostgresDetail
impl Debug for PostgresDetail
Sourceimpl Default for PostgresDetail
impl Default for PostgresDetail
Sourceimpl<'de> Deserialize<'de> for PostgresDetail
impl<'de> Deserialize<'de> for PostgresDetail
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more