pub struct PrivateServiceDetails {Show 16 fields
pub autoscaling: Option<PrivateServiceDetailsAutoscaling>,
pub build_plan: Option<BuildPlan>,
pub disk: Option<PrivateServiceDetailsDisk>,
pub env: Option<ServiceEnv>,
pub env_specific_details: Option<EnvSpecificDetails>,
pub max_shutdown_delay_seconds: Option<MaxShutdownDelaySeconds>,
pub num_instances: Option<i64>,
pub open_ports: Vec<ServerPort>,
pub parent_server: Option<Resource>,
pub plan: Option<Plan>,
pub previews: Option<Previews>,
pub pull_request_previews_enabled: Option<PullRequestPreviewsEnabled>,
pub region: Option<Region>,
pub runtime: Option<ServiceRuntime>,
pub ssh_address: Option<SshAddress>,
pub url: Option<String>,
}Expand description
PrivateServiceDetails
JSON schema
{
"type": "object",
"properties": {
"autoscaling": {
"type": "object",
"properties": {
"criteria": {
"type": "object",
"properties": {
"cpu": {
"type": "object",
"properties": {
"enabled": {
"default": false,
"type": "boolean"
},
"percentage": {
"description": "Determines when your service will be
scaled. If the average resource utilization is significantly above/below
the target, we will increase/decrease the number of instances.\n",
"type": "integer"
}
}
},
"memory": {
"type": "object",
"properties": {
"enabled": {
"default": false,
"type": "boolean"
},
"percentage": {
"description": "Determines when your service will be
scaled. If the average resource utilization is significantly above/below
the target, we will increase/decrease the number of instances.\n",
"type": "integer"
}
}
}
}
},
"enabled": {
"default": false,
"type": "boolean"
},
"max": {
"description": "The maximum number of instances for the
service",
"type": "integer"
},
"min": {
"description": "The minimum number of instances for the
service",
"type": "integer"
}
}
},
"buildPlan": {
"$ref": "#/components/schemas/buildPlan"
},
"disk": {
"type": "object",
"properties": {
"id": {
"examples": [
"dsk-cph1rs3idesc73a2b2mg"
],
"type": "string",
"pattern": "^dsk-[0-9a-z]{20}$"
},
"mountPath": {
"type": "string"
},
"name": {
"type": "string"
},
"sizeGB": {
"type": "integer"
}
}
},
"env": {
"$ref": "#/components/schemas/serviceEnv"
},
"envSpecificDetails": {
"$ref": "#/components/schemas/envSpecificDetails"
},
"maxShutdownDelaySeconds": {
"$ref": "#/components/schemas/maxShutdownDelaySeconds"
},
"numInstances": {
"description": "For a *manually* scaled service, this is the number
of instances the service is scaled to. DOES NOT indicate the number of
running instances for an *autoscaled* service.",
"type": "integer"
},
"openPorts": {
"type": "array",
"items": {
"$ref": "#/components/schemas/serverPort"
}
},
"parentServer": {
"$ref": "#/components/schemas/resource"
},
"plan": {
"$ref": "#/components/schemas/plan"
},
"previews": {
"$ref": "#/components/schemas/previews"
},
"pullRequestPreviewsEnabled": {
"$ref": "#/components/schemas/pullRequestPreviewsEnabled"
},
"region": {
"$ref": "#/components/schemas/region"
},
"runtime": {
"$ref": "#/components/schemas/serviceRuntime"
},
"sshAddress": {
"$ref": "#/components/schemas/sshAddress"
},
"url": {
"type": "string"
}
}
}Fields
autoscaling: Option<PrivateServiceDetailsAutoscaling>build_plan: Option<BuildPlan>disk: Option<PrivateServiceDetailsDisk>env: Option<ServiceEnv>env_specific_details: Option<EnvSpecificDetails>max_shutdown_delay_seconds: Option<MaxShutdownDelaySeconds>num_instances: Option<i64>For a manually scaled service, this is the number of instances the service is scaled to. DOES NOT indicate the number of running instances for an autoscaled service.
open_ports: Vec<ServerPort>parent_server: Option<Resource>plan: Option<Plan>previews: Option<Previews>pull_request_previews_enabled: Option<PullRequestPreviewsEnabled>region: Option<Region>runtime: Option<ServiceRuntime>ssh_address: Option<SshAddress>url: Option<String>Trait Implementations
Sourceimpl Clone for PrivateServiceDetails
impl Clone for PrivateServiceDetails
Sourcefn clone(&self) -> PrivateServiceDetails
fn clone(&self) -> PrivateServiceDetails
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PrivateServiceDetails
impl Debug for PrivateServiceDetails
Sourceimpl Default for PrivateServiceDetails
impl Default for PrivateServiceDetails
Sourceimpl<'de> Deserialize<'de> for PrivateServiceDetails
impl<'de> Deserialize<'de> for PrivateServiceDetails
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<PrivateServiceDetails> for ServiceServiceDetails
impl From<PrivateServiceDetails> for ServiceServiceDetails
Sourcefn from(value: PrivateServiceDetails) -> Self
fn from(value: PrivateServiceDetails) -> Self
Converts to this type from the input type.