pub struct RoutePatch {
pub priority: Option<i64>,
}Expand description
RoutePatch
JSON schema
{
"type": "object",
"properties": {
"priority": {
"description": "Redirect and Rewrite Rules are applied in priority
order starting at 0. Moves this route to the specified priority and
adjusts other route priorities accordingly.",
"type": "integer",
"x-go-type": "*int"
}
}
}Fields
priority: Option<i64>Redirect and Rewrite Rules are applied in priority order starting at 0. Moves this route to the specified priority and adjusts other route priorities accordingly.