ServicePost

Struct ServicePost 

pub struct ServicePost {
Show 13 fields pub auto_deploy: Option<AutoDeploy>, pub branch: Option<String>, pub build_filter: Option<BuildFilter>, pub env_vars: Vec<ServicePostEnvVarsItem>, pub environment_id: Option<String>, pub image: Option<Image>, pub name: Option<String>, pub owner_id: Option<String>, pub repo: Option<String>, pub root_dir: Option<String>, pub secret_files: Vec<SecretFileInput>, pub service_details: Option<ServicePostServiceDetails>, pub type_: Option<ServiceType>,
}
ServicePost

JSON schema
{
 "type": "object",
 "properties": {
   "autoDeploy": {
     "$ref": "#/components/schemas/autoDeploy"
   },
   "branch": {
     "description": "The repo branch to pull, build, and deploy. If
omitted, uses the repository's default branch.",
     "type": "string"
   },
   "buildFilter": {
     "$ref": "#/components/schemas/buildFilter"
   },
   "envVars": {
     "type": "array",
     "items": {
       "type": "object",
       "oneOf": [
         {
           "type": "object",
           "properties": {
             "key": {
               "type": "string"
             },
             "value": {
               "type": "string"
             }
           }
         },
         {
           "type": "object",
           "properties": {
             "generateValue": {
               "description": "If true, Render generates a strong random
value for this environment variable on creation. Cannot be combined with
`value`.",
               "type": "boolean"
             },
             "key": {
               "type": "string"
             }
           }
         }
       ]
     }
   },
   "environmentId": {
     "description": "The ID of the environment the service belongs to,
if any. Obtain an environment's ID from its Settings page in the Render
Dashboard.",
     "type": "string"
   },
   "image": {
     "$ref": "#/components/schemas/image"
   },
   "name": {
     "description": "The service's name. Must be unique within the
workspace.",
     "type": "string"
   },
   "ownerId": {
     "description": "The ID of the workspace the service belongs to.
Obtain your workspace's ID from its Settings page in the Render
Dashboard.",
     "type": "string"
   },
   "repo": {
     "description": "The service's repository URL. Do not specify a
branch in this string (use the `branch` parameter instead).",
     "examples": [
       "https://github.com/render-examples/flask-hello-world"
     ],
     "type": "string"
   },
   "rootDir": {
     "type": "string"
   },
   "secretFiles": {
     "type": "array",
     "items": {
       "$ref": "#/components/schemas/secretFileInput"
     }
   },
   "serviceDetails": {
     "oneOf": [
       {
         "$ref": "#/components/schemas/staticSiteDetailsPOST"
       },
       {
         "$ref": "#/components/schemas/webServiceDetailsPOST"
       },
       {
         "$ref": "#/components/schemas/privateServiceDetailsPOST"
       },
       {
         "$ref": "#/components/schemas/backgroundWorkerDetailsPOST"
       },
       {
         "$ref": "#/components/schemas/cronJobDetailsPOST"
       }
     ]
   },
   "type": {
     "$ref": "#/components/schemas/serviceType"
   }
 }
}

Fields

auto_deploy: Option<AutoDeploy>branch: Option<String>

The repo branch to pull, build, and deploy. If omitted, uses the repository’s default branch.

build_filter: Option<BuildFilter>env_vars: Vec<ServicePostEnvVarsItem>environment_id: Option<String>

The ID of the environment the service belongs to, if any. Obtain an environment’s ID from its Settings page in the Render Dashboard.

image: Option<Image>name: Option<String>

The service’s name. Must be unique within the workspace.

owner_id: Option<String>

The ID of the workspace the service belongs to. Obtain your workspace’s ID from its Settings page in the Render Dashboard.

repo: Option<String>

The service’s repository URL. Do not specify a branch in this string (use the branch parameter instead).

root_dir: Option<String>secret_files: Vec<SecretFileInput>service_details: Option<ServicePostServiceDetails>type_: Option<ServiceType>