CreateDeployBody

Struct CreateDeployBody 

pub struct CreateDeployBody {
    pub clear_cache: String,
    pub commit_id: Option<String>,
    pub deploy_mode: Option<DeployMode>,
    pub image_url: Option<String>,
}
CreateDeployBody

JSON schema
{
 "type": "object",
 "properties": {
   "clearCache": {
     "description": "If `clear`, Render clears the service's build cache
before deploying. This can be useful if you're experiencing issues with
your build.",
     "default": "do_not_clear",
     "type": "string"
   },
   "commitId": {
     "description": "The SHA of a specific Git commit to deploy for a service. Defaults to the latest commit on the service's connected branch.\n\nNote that deploying a specific commit with this endpoint does not disable autodeploys for the service.\n\nYou can toggle autodeploys for your service with the [Update service](https://api-docs.render.com/reference/update-service) endpoint or in the Render Dashboard.\n\nNot supported for cron jobs.\n",
     "type": "string"
   },
   "deployMode": {
     "$ref": "#/components/schemas/DeployMode"
   },
   "imageUrl": {
     "description": "The URL of the image to deploy for an image-backed
service.\n\nThe host, repository, and image name all must match the
currently configured image for the service.\n",
     "type": "string"
   }
 }
}

Fields

clear_cache: String

If clear, Render clears the service’s build cache before deploying. This can be useful if you’re experiencing issues with your build.

commit_id: Option<String>

The SHA of a specific Git commit to deploy for a service. Defaults to the latest commit on the service’s connected branch.

Note that deploying a specific commit with this endpoint does not disable autodeploys for the service.

You can toggle autodeploys for your service with the Update service endpoint or in the Render Dashboard.

Not supported for cron jobs.

deploy_mode: Option<DeployMode>image_url: Option<String>

The URL of the image to deploy for an image-backed service.

The host, repository, and image name all must match the currently configured image for the service.