pub struct PostgresPostInput {Show 16 fields
pub database_name: String,
pub database_user: String,
pub datadog_api_key: Option<String>,
pub datadog_site: Option<String>,
pub disk_size_gb: Option<i64>,
pub enable_disk_autoscaling: bool,
pub enable_high_availability: bool,
pub environment_id: Option<String>,
pub ip_allow_list: Vec<CidrBlockAndDescription>,
pub name: Option<String>,
pub owner_id: Option<String>,
pub parameter_overrides: Option<PostgresParameterOverrides>,
pub plan: Option<String>,
pub read_replicas: Option<ReadReplicasInput>,
pub region: Option<Region>,
pub version: Option<PostgresVersion>,
}Expand description
Input for creating a database
JSON schema
{
"description": "Input for creating a database",
"type": "object",
"properties": {
"databaseName": {
"default": "randomly generated",
"type": "string"
},
"databaseUser": {
"default": "randomly generated",
"type": "string"
},
"datadogAPIKey": {
"description": "The Datadog API key for the Datadog agent to
monitor the new database.",
"type": "string"
},
"datadogSite": {
"description": "Datadog region to use for monitoring the new
database. Defaults to 'US1'.",
"examples": [
"US1"
],
"type": "string"
},
"diskSizeGB": {
"description": "The number of gigabytes of disk space to allocate
for the database",
"type": "integer"
},
"enableDiskAutoscaling": {
"default": false,
"type": "boolean"
},
"enableHighAvailability": {
"default": false,
"type": "boolean"
},
"environmentId": {
"type": "string"
},
"ipAllowList": {
"type": "array",
"items": {
"$ref": "#/components/schemas/cidrBlockAndDescription"
}
},
"name": {
"description": "The name of the database as it will appear in the
Render Dashboard",
"type": "string"
},
"ownerId": {
"description": "The ID of the workspace to create the database
for",
"type": "string"
},
"parameterOverrides": {
"$ref": "#/components/schemas/postgresParameterOverrides"
},
"plan": {
"type": "string"
},
"readReplicas": {
"$ref": "#/components/schemas/readReplicasInput"
},
"region": {
"$ref": "#/components/schemas/region"
},
"version": {
"$ref": "#/components/schemas/postgresVersion"
}
}
}Fields
database_name: Stringdatabase_user: Stringdatadog_api_key: Option<String>The Datadog API key for the Datadog agent to monitor the new database.
datadog_site: Option<String>Datadog region to use for monitoring the new database. Defaults to ‘US1’.
disk_size_gb: Option<i64>The number of gigabytes of disk space to allocate for the database
enable_disk_autoscaling: boolenable_high_availability: boolenvironment_id: Option<String>ip_allow_list: Vec<CidrBlockAndDescription>name: Option<String>The name of the database as it will appear in the Render Dashboard
owner_id: Option<String>The ID of the workspace to create the database for
parameter_overrides: Option<PostgresParameterOverrides>plan: Option<String>read_replicas: Option<ReadReplicasInput>region: Option<Region>version: Option<PostgresVersion>Trait Implementations
Sourceimpl Clone for PostgresPostInput
impl Clone for PostgresPostInput
Sourcefn clone(&self) -> PostgresPostInput
fn clone(&self) -> PostgresPostInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PostgresPostInput
impl Debug for PostgresPostInput
Sourceimpl Default for PostgresPostInput
impl Default for PostgresPostInput
Sourceimpl<'de> Deserialize<'de> for PostgresPostInput
impl<'de> Deserialize<'de> for PostgresPostInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more